'use strict';

var _ReferConstants = require('../constants/ReferConstants');

var _YYReferUtils = require('../utils/YYReferUtils');

var _ = require('lodash');
var assign = _.assign;


function getRefinfo() {
    var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {
        refinfokey: null, // 参照key
        info: null, //参照信息
        often: null, // 常用数据
        tree: null,
        grid: null,
        treegrid: null,
        doReload: false,
        showMsg: null,
        loadingReferTree: false,
        loadingReferGrid: false,
        innerFilterObject: {}
    };
    var action = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : { type: type };

    switch (action.type) {
        case _ReferConstants.GET_PFREFINFO_BYCODE_SUCCESS:
            return assign({}, state, {
                refinfokey: action.key,
                info: action.data,
                treegrid: null,
                doReload: false,
                showMsg: null
            });
        case _ReferConstants.GET_PFREFINFO_BYCODE_ERROR:
            return assign({}, state, {
                info: null,
                doReload: false,
                showMsg: null
            });
        case _ReferConstants.GET_PFREFER_OFTEN_SUCCESS:
            return assign({}, state, {
                often: action.data,
                showMsg: null
            });
        case _ReferConstants.SAVE_PFREFER_OFTEN_SUCCESS:
            return assign({}, state, {
                often: action.data,
                showMsg: action.ifShowMsg === true ? { 'success': '保存常用成功' } : null
            });
        case _ReferConstants.SAVE_PFREFER_OFTEN_ERROR:
            return assign({}, state, {
                showMsg: { 'error': action.errorMsg }
            });
        case _ReferConstants.DELETE_PFREFER_OFTEN_SUCCESS:
            return assign({}, state, {
                often: action.data,
                showMsg: null
            });
        case _ReferConstants.DELETE_PFREFER_OFTEN_ERROR:
            return assign({}, state, {
                showMsg: { 'error': action.errorMsg }
            });
        case _ReferConstants.GET_PFTREEDATA_REF_SUCCESS:
            return assign({}, state, {
                tree: action.data,
                //树切换时，清空树表中的表数据,但是保留表头
                // treegrid: {"header":state.treegrid?state.treegrid.header:null, data:{}},
                doReload: false,
                showMsg: null,
                lasttime: action.lasttime++
            });
        case _ReferConstants.GET_PFTREEDATA_REF_ERROR:
            return assign({}, state, {
                tree: null,
                doReload: false,
                showMsg: null
            });
        case _ReferConstants.GET_PFGRIDDATA_REF_SUCCESS:
            return assign({}, state, {
                grid: action.data,
                doReload: false,
                showMsg: null
            });
        case _ReferConstants.GET_PFGRIDDATA_REF_ERROR:
            return assign({}, state, {
                grid: null,
                doReload: false,
                showMsg: null
            });
        case _ReferConstants.GET_PFTREEGRIDDATA_REF_SUCCESS:
            return assign({}, state, {
                treegrid: action.data,
                doReload: false,
                showMsg: null
            });
        case _ReferConstants.GET_PFTREEGRIDDATA_REF_ERROR:
            return assign({}, state, {
                treegrid: null,
                doReload: false,
                showMsg: null
            });

        case _ReferConstants.GET_PFTREE_AND_GRID_REF_SUCCESS:
            return assign({}, state, {
                tree: action.treeData,
                treegrid: action.treeGridData,
                doReload: false,
                showMsg: null
            });
        case _ReferConstants.DO_PFRELOAD_REF:
            return assign({}, state, {
                doReload: true,
                showMsg: null
            });
        case _ReferConstants.DO_PFCLEAR_PREDATAS:
            return assign({}, state, {
                // info : null,
                tree: null,
                grid: null,
                treegrid: null,
                doReload: false,
                showMsg: null
            });
        case _ReferConstants.LOADING_PFREFER_TREE:
            return assign({}, state, {
                loadingReferTree: action.loadingReferTree
            });
        case _ReferConstants.LOADING_PFREFER_GRID:
            return assign({}, state, {
                loadingReferGrid: action.loadingReferGrid
            });
        case _ReferConstants.SAVE_PFINNER_FILTER_VALUE:
            var data = (0, _YYReferUtils.assignObject)(state.innerFilterObject, action.data);
            return assign({}, state, {
                innerFilterObject: data
            });
        case _ReferConstants.DEL_PFINNER_FILTER_VALUE:
            if (state && _.isObject(state.innerFilterObject)) {
                delete state.innerFilterObject['' + action.key];
            }
            delete state['' + action.key];
            return state;
        default:
            return state;
    }
}
module.exports = getRefinfo;